summary refs log tree commit diff stats
path: root/src/common/dbus
diff options
context:
space:
mode:
authorBerke Viktor <bviktor@hexchat.org>2012-10-30 08:58:50 +0100
committerBerke Viktor <bviktor@hexchat.org>2012-10-30 08:58:50 +0100
commit8d6f4d9d40c68f3174cbe94f7107dea74d00d5fc (patch)
tree5c2cdf86338b10b5d4202491a03d84f5ae4126e5 /src/common/dbus
parente681eafa78262d0c177832d67900687f2c938081 (diff)
Some remaining fixes
Diffstat (limited to 'src/common/dbus')
-rw-r--r--src/common/dbus/dbus-client.c12
-rw-r--r--src/common/dbus/dbus-client.h2
-rw-r--r--src/common/dbus/dbus-plugin.c4
-rw-r--r--src/common/dbus/dbus-plugin.h4
-rw-r--r--src/common/dbus/example.c4
5 files changed, 13 insertions, 13 deletions
diff --git a/src/common/dbus/dbus-client.h b/src/common/dbus/dbus-client.h
index cafc2b71..a689e978 100644
--- a/src/common/dbus/dbus-client.h
+++ b/src/common/dbus/dbus-client.h
@@ -22,6 +22,6 @@
 #ifndef __DBUS_PLUGIN_H__
 #define __DBUS_PLUGIN_H__
 
-void xchat_remote (void);
+void hexchat_remote (void);
 
 #endif /* __DBUS_PLUGIN_H__ */
diff --git a/src/common/dbus/dbus-plugin.c b/src/common/dbus/dbus-plugin.c
index cba106a9..b62bfda5 100644
--- a/src/common/dbus/dbus-plugin.c
+++ b/src/common/dbus/dbus-plugin.c
@@ -1,4 +1,4 @@
-/* dbus-plugin.c - xchat plugin for remote access using D-Bus
+/* dbus-plugin.c - hexchat plugin for remote access using D-Bus
  * Copyright (C) 2006 Claessens Xavier
  *
  * This program is free software; you can redistribute it and/or modify
@@ -510,7 +510,7 @@ remote_object_get_prefs (RemoteObject *obj,
 		*ret_type = 0;
 		return TRUE;
 	}
-	*ret_type = xchat_get_prefs (ph, name, &str, ret_int);
+	*ret_type = hexchat_get_prefs (ph, name, &str, ret_int);
 	*ret_str = g_strdup (str);
 
 	return TRUE;
diff --git a/src/common/dbus/example.c b/src/common/dbus/example.c
index 98f7fecc..1eebdfcf 100644
--- a/src/common/dbus/example.c
+++ b/src/common/dbus/example.c
@@ -73,7 +73,7 @@ test_command_cb (DBusGProxy *proxy,
 					G_TYPE_INVALID, G_TYPE_INVALID)) {
 			write_error ("Failed to complete unhook", &error);
 		}
-		/* Now if you write "/test blah" again in the xchat window
+		/* Now if you write "/test blah" again in the HexChat window
 		 * you'll get a "Unknown command" error message */
 		g_print ("test command received: %s\n", word_eol[1]);
 		if (!dbus_g_proxy_call (proxy, "Print",
@@ -193,7 +193,7 @@ main (int argc, char **argv)
 				     G_CALLBACK (unload_cb),
 				     NULL, NULL);
 
-	/* Now you can write on the xchat windows: "/test arg1 arg2 ..." */
+	/* Now you can write on the HexChat windows: "/test arg1 arg2 ..." */
 	mainloop = g_main_loop_new (NULL, FALSE);
 	g_main_loop_run (mainloop);
diff --git a/src/common/dbus/dbus-client.c b/src/common/dbus/dbus-client.c
index 6f146261..70b94b50 100644
--- a/src/common/dbus/dbus-client.c
+++ b/src/common/dbus/dbus-client.c
@@ -40,7 +40,7 @@ write_error (char *message,
 }
 
 void
-xchat_remote (void)
+hexchat_remote (void)
 /* TODO: dbus_g_connection_unref (connection) are commented because it makes
  * dbus to crash. Fixed in dbus >=0.70 ?!?
  * https://launchpad.net/distros/ubuntu/+source/dbus/+bug/54375
@@ -49,7 +49,7 @@ xchat_remote (void)
 	DBusGConnection *connection;
 	DBusGProxy *dbus = NULL;
 	DBusGProxy *remote_object = NULL;
-	gboolean xchat_running;
+	gboolean hexchat_running;
 	GError *error = NULL;
 	char *command = NULL;
 
@@ -73,7 +73,7 @@ xchat_remote (void)
 		return;
 	}
 
 	/* Checks if xchat is already running */
 	dbus = dbus_g_proxy_new_for_name (connection,
 					  DBUS_SERVICE_DBUS,
 					  DBUS_PATH_DBUS,
@@ -81,14 +81,14 @@ xchat_remote (void)
 	if (!dbus_g_proxy_call (dbus, "NameHasOwner", &error,
 				G_TYPE_STRING, DBUS_SERVICE,
 				G_TYPE_INVALID,
-				G_TYPE_BOOLEAN, &xchat_running,
+				G_TYPE_BOOLEAN, &hexchat_running,
 				G_TYPE_INVALID)) {
 		write_error (_("Failed to complete NameHasOwner"), &error);
-		xchat_running = FALSE;
+		hexchat_running = FALSE;
 	}
 	g_object_unref (dbus);
 
-	if (!xchat_running) {
+	if (!hexchat_running) {
 		//dbus_g_connection_unref (connection);
 		return;
 	}
@@ -73,7 +73,7 @@ xchat_remote (void)
 	}
 
-	/* Checks if xchat is already running */
+	/* Checks if HexChat is already running */
 	dbus = dbus_g_proxy_new_for_name (connection,
 					  DBUS_SERVICE_DBUS,
diff --git a/src/common/dbus/dbus-plugin.h b/src/common/dbus/dbus-plugin.h
index bda8f61c..49dded9c 100644
--- a/src/common/dbus/dbus-plugin.h
+++ b/src/common/dbus/dbus-plugin.h
@@ -1,4 +1,4 @@
 /* dbus-plugin.c - xchat plugin for remote access using DBUS
  * Copyright (C) 2006 Claessens Xavier
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,7 @@
 #ifndef XCHAT_DBUS_PLUGIN_H
 #define XCHAT_DBUS_PLUGIN_H
 
-int	dbus_plugin_init	(xchat_plugin *plugin_handle,
+int	dbus_plugin_init	(hexchat_plugin *plugin_handle,
 				 char **plugin_name,
 				 char **plugin_desc,
 				 char **plugin_version,
@@ -1,4 +1,4 @@
-/* dbus-plugin.c - xchat plugin for remote access using DBUS
+/* dbus-plugin.c - hexchat plugin for remote access using DBUS
  * Copyright (C) 2006 Claessens Xavier
  *